@@ -6,6 +6,7 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package send
 
@@ -22,9 +23,9 @@ import (
 	"time"
 
 	"github.com/golang/glog"
-	"github.com/open-cluster-management/search-collector/pkg/config"
-	"github.com/open-cluster-management/search-collector/pkg/reconciler"
-	tr "github.com/open-cluster-management/search-collector/pkg/transforms"
+	"github.com/stolostron/search-collector/pkg/config"
+	"github.com/stolostron/search-collector/pkg/reconciler"
+	tr "github.com/stolostron/search-collector/pkg/transforms"
 )
 
 // A UID of a node to be deleted, and the time at which it was deleted.
@@ -164,6 +165,15 @@ func (s *Sender) sendWithRetry(payload Payload, expectedTotalResources int, expe
 			glog.Warningf("Received busy response from Aggregator. Resending in %d ms.", waitMS)
 			time.Sleep(time.Duration(waitMS) * time.Millisecond)
 			continue
+		} else if sendError != nil && sendError.Error() == "401 Unauthorized" {
+			retry++
+			waitMS := int(math.Min(float64(retry*15*1000), float64(config.Cfg.MaxBackoffMS)))
+			glog.Warningf("Received Unauthorized response from Aggregator. Resending in %d ms after resetting config.",
+				waitMS)
+			config.InitConfig() // re-initialize config to get the latest certificate.
+			s.httpClient = getHTTPSClient()
+			time.Sleep(time.Duration(waitMS) * time.Millisecond)
+			continue
 		}
 		return sendError
 	}
@@ -195,6 +205,9 @@ func (s *Sender) send(payload Payload, expectedTotalResources int, expectedTotal
 	} else if resp.StatusCode != http.StatusOK {
 		msg := fmt.Sprintf("POST to: %s responded with error. StatusCode: %d  Message: %s",
 			s.aggregatorURL+s.aggregatorSyncPath, resp.StatusCode, resp.Status)
+		if resp.StatusCode == http.StatusUnauthorized {
+			msg = "401 Unauthorized"
+		}
 		return errors.New(msg)
 	}
 
