@@ -4,6 +4,8 @@ OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
 The source code for this program is not published or otherwise divested of its trade secrets,
 irrespective of what has been deposited with the U.S. Copyright Office.
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 */
 
 package transforms
@@ -11,7 +13,7 @@ package transforms
 import (
 	"testing"
 
-	app "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/apis/apps/v1"
+	app "github.com/stolostron/multicloud-operators-placementrule/pkg/apis/apps/v1"
 )
 
 func TestTransformPlacementRule(t *testing.T) {
